@@ -114,9 +114,10 @@ static int profile_indent;
 static void
 profile_add_indent (int indent)
 {
-        profile_indent += indent;
-        if (profile_indent < 0)
-                g_error ("You screwed up your indentation");
+	profile_indent += indent;
+	if (profile_indent < 0) {
+		g_error ("You screwed up your indentation");
+	}
 }
 
 static void
@@ -125,22 +126,25 @@ _ncb_profile_log (const char *func,
 		  const char *msg1,
 		  const char *msg2)
 {
-        char *str;
+	char *str;
 
-        if (indent < 0)
-                profile_add_indent (indent);
+	if (indent < 0) {
+		profile_add_indent (indent);
+	}
 
-        if (profile_indent == 0)
-                str = g_strdup_printf ("MARK: %s: %s %s %s", G_STRLOC, func, msg1 ? msg1 : "", msg2 ? msg2 : "");
-        else
-                str = g_strdup_printf ("MARK: %s: %*c %s %s %s", G_STRLOC, profile_indent - 1, ' ', func, msg1 ? msg1 : "", msg2 ? msg2 : "");
+	if (profile_indent == 0) {
+		str = g_strdup_printf ("MARK: %s: %s %s %s", G_STRLOC, func, msg1 ? msg1 : "", msg2 ? msg2 : "");
+	} else {
+		str = g_strdup_printf ("MARK: %s: %*c %s %s %s", G_STRLOC, profile_indent - 1, ' ', func, msg1 ? msg1 : "", msg2 ? msg2 : "");
+	}
 
-        access (str, F_OK);
+	access (str, F_OK);
 
-        g_free (str);
+	g_free (str);
 
-        if (indent > 0)
-                profile_add_indent (indent);
+	if (indent > 0) {
+		profile_add_indent (indent);
+	}
 }
 
 #define profile_start(x, y) _ncb_profile_log (G_STRFUNC, PROFILE_INDENT, x, y)
@@ -155,8 +159,9 @@ _ncb_profile_log (const char *func,
 static void
 nautilus_burn_progress_write_data_free (NautilusBurnerWriteData *data)
 {
-	if (! data)
+	if (! data) {
 		return;
+	}
 
 	nautilus_burn_drive_unref (data->drive);
 
@@ -174,8 +179,9 @@ ncb_hig_dialog (GtkMessageType type,
 {
 	GtkWidget *error_dialog;
 
-	if (reason == NULL)
+	if (reason == NULL) {
 		g_warning ("ncb_hig_dialog called with reason == NULL");
+	}
 
 	error_dialog =
 		gtk_message_dialog_new (parent,
@@ -439,8 +445,9 @@ nautilus_burn_progress_cleanup (void)
 	nautilus_burn_progress_temp_files_cleanup ();
 
 	data = nautilus_burn_progress_get_write_data ();
-	if (data)
+	if (data) {
 		nautilus_burn_progress_write_data_free (data);
+	}
 }
 
 static int
@@ -576,8 +583,9 @@ ask_for_media (NautilusBurnDrive *drive,
 	g_free (type_string);
 
 	parent = (GtkWidget *)nautilus_burn_progress_get_window ();
-	if (!parent)
+	if (! parent) {
 		parent = glade_xml_get_widget (xml, "cdr_dialog");
+	}
 
 	dialog = ncb_hig_dialog (GTK_MESSAGE_INFO,
 				 _(title), _(msg), GTK_WINDOW (parent));
@@ -631,8 +639,9 @@ insert_media_request_cb (NautilusBurnRecorder *recorder,
 			     FALSE,
 			     info->size);
 
-	if (res == GTK_RESPONSE_CANCEL)
+	if (res == GTK_RESPONSE_CANCEL) {
 		return FALSE;
+	}
  
 	return TRUE;
 }
@@ -736,8 +745,9 @@ file_info_is_image (GnomeVFSFileInfo *info)
 
 	g_return_val_if_fail (info != NULL, FALSE);
 
-	if (!info->mime_type)
+	if (!info->mime_type) {
 		return FALSE;
+	}
 
 	is_image = (strcmp (info->mime_type, "application/x-cd-image") == 0);
 
@@ -1121,27 +1131,62 @@ request_media (NautilusBurnDrive *drive,
 	return TRUE;
 }
 
+/* Adapted from sound-juicer */
+static char *
+sanitize_filename (const char *path,
+		   gboolean    strip_chars)
+{
+	char *ret;
+
+	/* Skip leading periods, otherwise files disappear... */
+	while (*path == '.') {
+		path++;
+	}
+  
+	ret = g_strdup (path);
+	/* Replace path seperators with a hyphen */
+	g_strdelimit (ret, "/", '-');
+
+	if (strip_chars) {
+		/* Replace separators with a hyphen */
+		g_strdelimit (ret, "\\:|", '-');
+		/* Replace all other weird characters to whitespace */
+		g_strdelimit (ret, "*?&!\'\"$()`>{}", ' ');
+		/* Replace all whitespace with underscores */
+		/* TODO: I'd like this to compress whitespace aswell */
+		g_strdelimit (ret, "\t ", '_');
+	}
+
+	return ret;
+}
+
 static char *
 get_output_filename (const char *disc_name)
 {
 	char *filename         = NULL;
 	char *default_filename = NULL;
+	char *temp;
 
-	if (disc_name) {
+	if (disc_name != NULL) {
 		default_filename = g_strdup_printf ("%s.iso", disc_name);
 	}
 
-	if (! default_filename) {
+	if (default_filename == NULL) {
 		/* Translators: this is the filename of the image */
 		default_filename = g_strdup (_("image.iso"));
+	} else {
+		temp = sanitize_filename (default_filename, TRUE);
+		g_free (default_filename);
+		default_filename = temp;
 	}
 
 	/* Run the file selector and get the iso file name selected */
 	filename = select_iso_filename (default_filename);
 	g_free (default_filename);
 
-	if (! filename)
+	if (filename == NULL) {
 		return NULL;
+	}
 
 	/* Check if you have permission to create or
 	 * overwrite the file.
@@ -1420,14 +1465,16 @@ burn_cd (NautilusBurnDrive        *drive,
 	if (drive->type == NAUTILUS_BURN_DRIVE_TYPE_FILE) {
 		char *disc_name = NULL;
 
-		if (source_drive)
+		if (source_drive) {
 			disc_name = nautilus_burn_drive_get_media_label (source_drive);
+		}
 
 		filename = get_output_filename (disc_name);
 		g_free (disc_name);
 
-		if (! filename)
+		if (! filename) {
 			return NAUTILUS_BURN_RECORDER_RESULT_CANCEL;
+		}
 	} else {
 		if (source_iso == NULL) {
 			GConfClient *gc;
@@ -1463,8 +1510,9 @@ burn_cd (NautilusBurnDrive        *drive,
 			is_locked = nautilus_burn_drive_lock (drive, _("Burning CD"), NULL);
 			got_media = request_media (drive, burn_size, overburn, &try_overburn);
 
-			if (got_media)
+			if (got_media) {
 				media_type = nautilus_burn_drive_get_media_type (drive);
+			}
 
 			if (is_locked) {
 				nautilus_burn_drive_unlock (drive);
@@ -1484,17 +1532,20 @@ burn_cd (NautilusBurnDrive        *drive,
 	    && source_cue == NULL) {
 		NautilusBurnImageCreateFlags image_flags = 0;
 
-		if (debug)
+		if (debug) {
 			image_flags |= NAUTILUS_BURN_IMAGE_CREATE_DEBUG;
-		if (1)
+		}
+		if (1) {
 			image_flags |= NAUTILUS_BURN_IMAGE_CREATE_JOLIET;
+		}
 
 		cancel = CANCEL_MAKE_ISO;
 
 		if (filename != NULL) {
 
-			if (drive->type == NAUTILUS_BURN_DRIVE_TYPE_FILE)
+			if (drive->type == NAUTILUS_BURN_DRIVE_TYPE_FILE) {
 				image_flags |= NAUTILUS_BURN_IMAGE_CREATE_WARN_SPACE;
+			}
 
 			/* Don't warn on low space unless the user selected this file specifically */
 			if (source_drive) {
@@ -1671,8 +1722,9 @@ lookup_current_recorder (GladeXML *xml)
 
 	selection = glade_xml_get_widget (xml, "target_optionmenu");
 
-	if (! selection)
+	if (! selection) {
 		return NULL;
+	}
 
 	/* the drive is reffed */
 	drive = nautilus_burn_drive_selection_get_active (NAUTILUS_BURN_DRIVE_SELECTION (selection));
@@ -1689,8 +1741,9 @@ get_speed_selection (GtkWidget *combobox)
 
 	speed = 0;
 
-	if (! gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combobox), &iter))
+	if (! gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combobox), &iter)) {
 		return speed;
+	}
 
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX (combobox));
         gtk_tree_model_get (model, &iter, 1, &speed, -1);
@@ -1996,8 +2049,9 @@ verify_source_location_contents (const char *text_uri,
 	gint64    size;
 	int       res;
 
-	if (images)
+	if (images) {
 		*images = NULL;
+	}
 
 	size = estimate_size (text_uri, &unreadable_paths, &image_paths, &only_images);
 
@@ -2107,8 +2161,9 @@ verify_source_location_contents (const char *text_uri,
 		return FALSE;
 	}
 
-	if (size_out)
+	if (size_out) {
 		*size_out = size;
+	}
 
 	return TRUE;
 }
@@ -2148,8 +2203,9 @@ verify_source_image (const char           *text_uri,
 	/* TODO: is this close enough for the CD size? */
 	res = g_stat (text_uri, &stat_buf);
 
-	if (size_out)
+	if (size_out) {
 		*size_out = (gint64)stat_buf.st_size;
+	}
 
 	return TRUE;
 }
@@ -2234,8 +2290,9 @@ selection_dialog_response (GtkWidget                *dialog,
 			       overburn,
 			       burnproof);
 
-		if (drive)
+		if (drive) {
 			nautilus_burn_drive_unref (drive);
+		}
 
 		if (res == NAUTILUS_BURN_RECORDER_RESULT_CANCEL) {
 			gtk_main_quit ();
@@ -2290,8 +2347,9 @@ fill_selection_dialog (NautilusBurnerSourceData *burn_data)
 				burn_data->source_iso = g_strdup ((char *)image_paths->data);
 				g_list_foreach (image_paths, (GFunc)g_free, NULL);
 				g_list_free (image_paths);
-				if (! verify_source_image (burn_data->source_iso, &burn_data->size, &disc_name))
+				if (! verify_source_image (burn_data->source_iso, &burn_data->size, &disc_name)) {
 					goto done;
+				}
 			} else 
 				goto done;
 		}
